@@ -1,12 +1,12 @@
 package WordList::Test::OneTwo;
 
-our $DATE = '2018-03-22'; # DATE
-our $VERSION = '0.3.0'; # VERSION
+our $DATE = '2018-03-23'; # DATE
+our $VERSION = '0.3.1'; # VERSION
 
 use WordList;
 our @ISA = qw(WordList);
 
-# STATS
+our %STATS = ("shortest_word_len",3,"num_words_contains_unicode",0,"avg_word_len",3,"num_words",2,"num_words_contains_nonword_chars",0,"num_words_contains_whitespace",0,"longest_word_len",3); # STATS
 
 1;
 # ABSTRACT: Wordlist that contains "one" and "two"
@@ -21,7 +21,26 @@ WordList::Test::OneTwo - Wordlist that contains "one" and "two"
 
 =head1 VERSION
 
-This document describes version 0.3.0 of WordList::Test::OneTwo (from Perl distribution WordList), released on 2018-03-22.
+This document describes version 0.3.1 of WordList::Test::OneTwo (from Perl distribution WordList), released on 2018-03-23.
+
+=head1 SYNOPSIS
+
+ use WordList::Test::OneTwo;
+
+ my $wl = WordList::Test::OneTwo->new;
+
+ # Pick a (or several) random word(s) from the list
+ my $word = $wl->pick;
+ my @words = $wl->pick(3);
+
+ # Check if a word exists in the list
+ if ($wl->word_exists('foo')) { ... }
+
+ # Call a callback for each word
+ $wl->each_word(sub { my $word = shift; ... });
+
+ # Get all the words
+ my @all_words = $wl->all_words;
 
 =head1 HOMEPAGE
 
